==> configgen-1.14.tbz: bin/configgen.sh <==
#!/bin/sh
#
# Copyright (c) 2004-2005 Michael Johnson <ahze@FreeBSD.org>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# Needs the following ports
# gnu-autoconf, gnu-automake, gnu-libtool
# and gnomecommon if you want to use gnome.
#
# FreeBSD configgen.sh, Michael Johnson 2004/12/04
#  This script attempts to create a gnu-configure script, libtool files, etc
#  on FreeBSD.
#
# NOTES: Remember to tar -L ...
#
# $MCom: portstools/configgen.sh,v 1.14 2006/02/24 00:57:09 ahze Exp $
#

# Paths
LOCALBASE=${LOCALBASE:=/usr/local}
X11BASE=${X11BASE:=/usr/X11R6}
GTOOLSBASE=${GTOOLSBASE:=${LOCALBASE}/gnu-autotools}

case "x$1" in
	x-bsd)
	  ACLOCAL_SUFX=${ACLOCAL_SUFX:=15}
	  AUTOCONF_SUFX=${AUTOCONF_SUFX:=253}
	  AUTOHEADER_SUFX=${AUTOHEADER_SUFX:=253}
	  AUTOMAKE_SUFX=${AUTOMAKE_SUFX:=15}
	  LIBTOOLIZE_SUFX=${LIBTOOLIZE_SUFX}
	  ;;
	x-bsd19)          
	  ACLOCAL_SUFX=${ACLOCAL_SUFX:=19}
	  AUTOCONF_SUFX=${AUTOCONF_SUFX:=259}
	  AUTOHEADER_SUFX=${AUTOHEADER_SUFX:=259}
	  AUTOMAKE_SUFX=${AUTOMAKE_SUFX:=19}
	  LIBTOOLIZE_SUFX=${LIBTOOLIZE_SUFX}
	  ;;
	x-bsd14)
	  ACLOCAL_SUFX=${ACLOCAL_SUFX:=14}
	  AUTOCONF_SUFX=${AUTOCONF_SUFX:=213}
	  AUTOHEADER_SUFX=${AUTOHEADER_SUFX:=213}
	  AUTOMAKE_SUFX=${AUTOMAKE_SUFX:=14}
	  LIBTOOLIZE_SUFX=${LIBTOOLIZE_SUFX}
	  ;;
	x-gnome)
	  export PATH=$GTOOLSBASE/bin:$PATH
	  ACLOCAL_INCLUDES="-I $GTOOLSBASE/share/aclocal"
	  export REQUIRED_AUTOCONF_VERSION="2.59"
	  export REQUIRED_AUTOMAKE_VERSION="1.9"
	  export REQUIRED_LIBTOOL_VERSION="1.5"
	  ;;
	*)
	  export PATH=$GTOOLSBASE/bin:$PATH
	  ACLOCAL_INCLUDES="-I $GTOOLSBASE/share/aclocal"
	esac

# Global varibles
ACLOCAL=${ACLOCAL:=aclocal}${ACLOCAL_SUFX}
AUTOHEADER=${AUTOHEADER:=autoheader}${AUTOHEADER_SUFX}
AUTOMAKE=${AUTOMAKE:=automake}${AUTOMAKE_SUFX}
LIBTOOLIZE=${LIBTOOLIZE:=libtoolize}${LIBTOOLIZE_SUFX}
AUTOCONF=${AUTOCONF:=autoconf}${AUTOCONF_SUFX}
GNOME_GEN=${GNOME_GEN:=gnome-autogen.sh}

# Disable configure from running
export AUTOGEN_SUBDIR_MODE=1
export NOCONFIGURE=1
export NO_RUN_CONFIGURE=1

export ACLOCAL_FLAGS="${ACLOCAL_INCLUDES} -I ${LOCALBASE}/share/aclocal${ACLOCAL_SUFX} -I . -I ${LOCALBASE}/share/aclocal -I ${X11BASE}/share/aclocal"

# Check to see if we have everything installed.
check_install()
{
	for test in ${ACLOCAL} ${AUTOHEADER} ${AUTOMAKE} ${LIBTOOLIZE} ${AUTOCONF} ;
		do which ${test} >/dev/null || {
		  echo "${test} is missing! Can not continue!"
		  exit 1
		}; done
}

usage()
{
	echo "usage: Run `basename $0` in directory to create configure script"
	echo "[-gnu] [-gnome] [-help] [-bsd] [-bsd14|19] [<config>] [config args...]"

}

long_usage()
{
	usage
	echo " -gnu       Create generic gnu configure script"
	echo " -gnome     Create gnome specific configure script"
	echo " -bsd       Use FreeBSD auto-tools"
	echo "              (versions: libtool15, automake15, autoconf253)" 
	echo " -bsd14     Use FreeBSD auto-tools"
	echo "              (versions: libtool15, automake14, autoconf213)"
	echo " -bsd19     Use FreeBSD auto-tools"
	echo "              (versions: libtool15, automake19, autoconf259)"
	echo " <config>   Specify a auto-gen configure script"
	exit 0
}

autogen()
{
	check_install
if [ -f configure.ac ] ; then
	CONFIGURE_SCRIPT=configure.ac
else
	CONFIGURE_SCRIPT=configure.in
fi

	echo "===> Running ${ACLOCAL}..."
	${ACLOCAL} ${ACLOCAL_FLAGS}

if grep -Eq 'A.*_CONFIG_HEADER' ${CONFIGURE_SCRIPT} 2>/dev/null ; then
	echo "===> Running ${AUTOHEADER}..."
	${AUTOHEADER}
fi

if grep -Eq 'A.*_PROG_LIBTOOL' ${CONFIGURE_SCRIPT} 2>/dev/null ; then
	echo "===> Running ${LIBTOOLIZE}..."
	${LIBTOOLIZE} --automake --copy --force
fi

	echo "===> Running ${AUTOMAKE}..."
	${AUTOMAKE} --add-missing --copy

	echo "===> Running ${AUTOCONF}..."
	${AUTOCONF}

if [ -f configure ] ; then \
	echo "===> Configure script created successfully" ; \
else
	echo "===> Failed to create Configure script!" ; \
fi
}

gnome_autogen()
{
	check_install
if [ -f autogen.sh ] ; then
# http://developer.gnome.org/tools/cvs.html
	which ${GNOME_GEN} >/dev/null ||
	{
		echo "gnomecommon is missing, please install!"
		exit 1
	}
	sh ./autogen.sh $@ ;
else
	find_config
fi
}

find_config()
{
if [ -f "$1" ] ; then
	sh $1 ;
elif [ -f autogen.sh ] ; then
	sh ./autogen.sh $@ ;
elif [ -f bootstrap ] ; then
	sh ./bootstrap $@ ;
elif [ -f configure.in -o -f configure.ac ] ; then
	autogen ;
else
	usage ;
fi;
}

case "x$1" in
	x-bsd | x-bsd14 | x-bsd19 | x-gnu)
	  autogen
	  ;;
	x-gnome)
	  gnome_autogen
	  ;;
	x-h)
	  usage
	  ;;
	x-help)
	  long_usage
	  ;;
	*)
	  find_config
	  ;;
	esac

==> configgen-1.15.tbz: bin/configgen.sh <==
#!/bin/sh
#
# Copyright (c) 2004-2005 Michael Johnson <ahze@FreeBSD.org>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# Needs the following ports
# gnu-autoconf, gnu-automake, gnu-libtool
# and gnomecommon if you want to use gnome.
#
# FreeBSD configgen.sh, Michael Johnson 2004/12/04
#  This script attempts to create a gnu-configure script, libtool files, etc
#  on FreeBSD.
#
# NOTES: Remember to tar -L ...
#
# $MCom: portstools/configgen.sh,v 1.15 2006/05/11 15:50:26 ahze Exp $
#

# Paths
LOCALBASE=${LOCALBASE:=/usr/local}
X11BASE=${X11BASE:=/usr/X11R6}
GTOOLSBASE=${GTOOLSBASE:=${LOCALBASE}/gnu-autotools}

case "x$1" in
	x-bsd)
	  ACLOCAL_SUFX=${ACLOCAL_SUFX:=15}
	  AUTOCONF_SUFX=${AUTOCONF_SUFX:=253}
	  AUTOHEADER_SUFX=${AUTOHEADER_SUFX:=253}
	  AUTOMAKE_SUFX=${AUTOMAKE_SUFX:=15}
	  LIBTOOLIZE_SUFX=${LIBTOOLIZE_SUFX}
	  ;;
	x-bsd19)          
	  ACLOCAL_SUFX=${ACLOCAL_SUFX:=19}
	  AUTOCONF_SUFX=${AUTOCONF_SUFX:=259}
	  AUTOHEADER_SUFX=${AUTOHEADER_SUFX:=259}
	  AUTOMAKE_SUFX=${AUTOMAKE_SUFX:=19}
	  LIBTOOLIZE_SUFX=${LIBTOOLIZE_SUFX}
	  ;;
	x-bsd14)
	  ACLOCAL_SUFX=${ACLOCAL_SUFX:=14}
	  AUTOCONF_SUFX=${AUTOCONF_SUFX:=213}
	  AUTOHEADER_SUFX=${AUTOHEADER_SUFX:=213}
	  AUTOMAKE_SUFX=${AUTOMAKE_SUFX:=14}
	  LIBTOOLIZE_SUFX=${LIBTOOLIZE_SUFX}
	  ;;
	x-gnome)
	  export PATH=$GTOOLSBASE/bin:$PATH
	  ACLOCAL_INCLUDES="-I $GTOOLSBASE/share/aclocal"
	  export REQUIRED_AUTOCONF_VERSION="2.59"
	  export REQUIRED_AUTOMAKE_VERSION="1.9"
	  export REQUIRED_LIBTOOL_VERSION="1.5"
	  ;;
	*)
	  export PATH=$GTOOLSBASE/bin:$PATH
	  ACLOCAL_INCLUDES="-I $GTOOLSBASE/share/aclocal"
	esac

# Global varibles
ACLOCAL=${ACLOCAL:=aclocal}${ACLOCAL_SUFX}
AUTOHEADER=${AUTOHEADER:=autoheader}${AUTOHEADER_SUFX}
AUTOMAKE=${AUTOMAKE:=automake}${AUTOMAKE_SUFX}
LIBTOOLIZE=${LIBTOOLIZE:=libtoolize}${LIBTOOLIZE_SUFX}
AUTOCONF=${AUTOCONF:=autoconf}${AUTOCONF_SUFX}
GNOME_GEN=${GNOME_GEN:=gnome-autogen.sh}

# Disable configure from running
export AUTOGEN_SUBDIR_MODE=1
export NOCONFIGURE=1
export NO_RUN_CONFIGURE=1

export ACLOCAL_FLAGS="${ACLOCAL_INCLUDES} -I ${LOCALBASE}/share/aclocal${ACLOCAL_SUFX} -I . -I ${LOCALBASE}/share/aclocal -I ${X11BASE}/share/aclocal"

# Check to see if we have everything installed.
check_install()
{
	for test in ${ACLOCAL} ${AUTOHEADER} ${AUTOMAKE} ${LIBTOOLIZE} ${AUTOCONF} ;
		do which ${test} >/dev/null || {
		  echo "${test} is missing! Can not continue!"
		  exit 1
		}; done
}

usage()
{
	echo "usage: Run `basename $0` in directory to create configure script"
	echo "[-gnu] [-gnome] [-f] [-help] [-bsd] [-bsd14|19] [<config>] [config args...]"

}

long_usage()
{
	usage
	echo " -gnu       Create generic gnu configure script"
	echo " -gnome     Create gnome specific configure script"
	echo " -bsd       Use FreeBSD auto-tools"
	echo "              (versions: libtool15, automake15, autoconf253)" 
	echo " -bsd14     Use FreeBSD auto-tools"
	echo "              (versions: libtool15, automake14, autoconf213)"
	echo " -bsd19     Use FreeBSD auto-tools"
	echo "              (versions: libtool15, automake19, autoconf259)"
	echo " -f         Find config (fall back on generic gnu)"
	echo " <config>   Specify a auto-gen configure script"
	exit 0
}

autogen()
{
	check_install
if [ -f configure.ac ] ; then
	CONFIGURE_SCRIPT=configure.ac
else
	CONFIGURE_SCRIPT=configure.in
fi

	echo "===> Running ${ACLOCAL}..."
	${ACLOCAL} ${ACLOCAL_FLAGS}

if grep -Eq 'A.*_CONFIG_HEADER' ${CONFIGURE_SCRIPT} 2>/dev/null ; then
	echo "===> Running ${AUTOHEADER}..."
	${AUTOHEADER}
fi

if grep -Eq 'A.*_PROG_LIBTOOL' ${CONFIGURE_SCRIPT} 2>/dev/null ; then
	echo "===> Running ${LIBTOOLIZE}..."
	${LIBTOOLIZE} --automake --copy --force
fi

	echo "===> Running ${AUTOMAKE}..."
	${AUTOMAKE} --add-missing --copy

	echo "===> Running ${AUTOCONF}..."
	${AUTOCONF}

if [ -f configure ] ; then \
	echo "===> Configure script created successfully" ; \
else
	echo "===> Failed to create Configure script!" ; \
fi
}

gnome_autogen()
{
	check_install
if [ -f autogen.sh ] ; then
# http://developer.gnome.org/tools/cvs.html
	which ${GNOME_GEN} >/dev/null ||
	{
		echo "gnomecommon is missing, please install!"
		exit 1
	}
	sh ./autogen.sh $@ ;
else
	find_config
fi
}

find_config()
{
if [ -f "$1" ] ; then
	sh $1 ;
elif [ -f autogen.sh ] ; then
	sh ./autogen.sh $@ ;
elif [ -f bootstrap ] ; then
	sh ./bootstrap $@ ;
elif [ -f configure.in -o -f configure.ac ] ; then
	autogen ;
else
	echo "Unable to find config"
	echo ""
	usage ;
fi;
}

case "x$1" in
	x-bsd | x-bsd14 | x-bsd19 | x-gnu)
	  autogen
	  ;;
	x-gnome)
	  gnome_autogen
	  ;;
	x-h)
	  usage
	  ;;
	x-help)
	  long_usage
	  ;;
	x-f)
	  find_config
	  ;;
	*)
	  if [ -f configure.in -o -f configure.ac ] ; then
	  	autogen	
	  else
		usage
	  fi
	esac
